# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

MAX_TURNS = 2

# Default max number of threads not exceeding Bedrock service quota:
# https://docs.aws.amazon.com/bedrock/latest/userguide/quotas.html
MAX_NUM_THREADS = 45
